#include "eeprom-killer.h"

char line[10];

int main()
{
	OSCCAL = 0xA4;

	init_uart();

	bootscreen();

	while(1)
	{
		uart_send_s("Enter EEPROM address to be destroyed (0-511): ");
		uart_get_s(line, 5);
		send_cursor_return;
		send_new_line;

		unsigned int address = atoi(line);
	
		if(address <= 511)
		{			
			uart_send_s("Content of address ");
			uart_send_s(itoa(address, line, 10));
			uart_send_s(" is: ");

			unsigned char x = ee_read_byte(address);
			uart_send_s(itoa(x, line, 10));

			send_cursor_return;
			send_new_line;
			send_new_line;
			
			uart_send_s("Really destroy (y/n)? ");
			uart_get_s(line, 3);
			send_cursor_return;
			send_new_line;
			
			if( (line[0] == 'y') && (line[1] == '\0') )
			{
				destroy(address);
			}		
		}

		else
		{
			uart_send_s("Invalid address entered.");
		}
	}
}

void bootscreen()
{
	uart_send_s("AVR EEPROM-KILLER v1.0");
	send_cursor_return;send_new_line;
}

void init_uart()
{
	// double speed
	UCSRA |= (1<<U2X);
	
	// RXCIE, TXCIE, RXEN, TXEN
	UCSRB = 0xD8;

	// asynchrone operation, no parity, 1 stop bit, 8 data bits
	UCSRC = 0x86;

	// set baud rate
	UBRRH = 0;
	UBRRL = 25;			// 3 -> 250k, 12 -> 76k8, 25 -> 38k4
}

void destroy(unsigned int address)
{
	unsigned char content = 0;
	unsigned char error = 0;
	unsigned long counter = 0;

	ee_write_byte(address, 0x00);

	uart_send_s("Write/erase cycles survived: ");

	while(error == 0)
	{
		content = ee_read_byte(address);

		itoa(content, line, 10);
		uart_send_s(line);
		
		if(content < 100)
		{
			uart_send_s(" ");		// one space, when content < 100

			if(content < 10)
			{
				uart_send_s(" ");	// one space, when content < 10
			}
		}

		uart_send_s(" ");	// space between content and counter

		ltoa(counter, line, 10);
		uart_send_s(line);

		if(content == 0x00)
		{
			ee_write_byte(address, 0xFF);
			
			if(ee_read_byte(address) != 0xFF)
			{
				error = 1;
			}
		}

		else if(content == 0xFF)
		{
			ee_write_byte(address, 0x00);

			if(ee_read_byte(address) != 0x00)
			{
				error = 1;
			}
		}

		else
		{
			error = 1;
		}

		send_backspace;	// kill 1st digit of counter

		if(counter > 9)
		{
			send_backspace;	// kill 2nd digit of counter

			if(counter > 99)
			{
				send_backspace;	// kill 3rd digit of counter

				if(counter > 999)
				{
					send_backspace;	// kill 4th digit of counter

					if(counter > 9999)
					{
						send_backspace;	// kill 5th digit of counter

						if(counter > 99999L)
						{
							send_backspace;	// kill 6th digit of counter

							if(counter > 999999L)
							{
								send_backspace;	// kill 7th digit of counter
							}
						}
					}	
				}
			}
		}

		send_backspace;	// kill space between counter and content

		send_backspace;	//  >-kill all digits of content
		send_backspace;	// 
		send_backspace;	// 
			
		counter++;
	}

	send_cursor_return;
	send_new_line;
	send_new_line;

	uart_send_s("EEPROM address ");
	uart_send_s(itoa(address, line, 10));
	uart_send_s(" died after ");
	uart_send_s(ltoa(counter, line, 10));
	uart_send_s(" cycles!");

	uart_get_s(line, 1);
	send_cursor_return;
	send_new_line;
	send_new_line;
}

