#include "eeprom-killer.h"

void ee_write_byte(unsigned int address, unsigned char data)
{
	//cli();

	// Set up address and data registers
	EEAR = address;
	EEDR = data;

	// Write logical one to EEMWE
	EECR |= (1<<EEMWE);

	// Start eeprom write by setting EEWE
	EECR |= (1<<EEWE);

	// Wait for completion of previous write
	while(EECR & (1<<EEWE));

	//sei();
}

void ee_write_word(unsigned int address, unsigned int data)
{
	unsigned char temp = (data & 0xFF00);
	ee_write_byte(address, temp);
	
	address++;
	temp = (data & 0xFF);
	ee_write_byte(address, temp);
}

void ee_write_long(unsigned int address, unsigned long data)
{
	unsigned char temp = (data & 0xFF000000);
	ee_write_byte(address, data);
	
	address++;
	temp = (data & 0xFF0000);
	ee_write_byte(address, data);
	
	address++;
	temp = (data & 0xFF00);
	ee_write_byte(address, data);
	
	address++;
	temp = (data & 0xFF);
	ee_write_byte(address, data);
}

unsigned char ee_read_byte(unsigned int address)
{
	while(EECR & (1<<EEWE))
	;

	// Set up address and data registers
	EEAR = address;

	// Start reading data from EEPROM address
	EECR |= (1<<EERE);

return EEDR;
}

unsigned int ee_read_word(unsigned int address)
{
	unsigned int content = ee_read_byte(address);
	content <<= 8;
	address++;

	content += ee_read_byte(address);

return content;
}

unsigned long ee_read_long(unsigned int address)
{
	unsigned long content = ee_read_byte(address);
	content <<= 8;
	address++;

	content += ee_read_byte(address);
	content <<= 8;
	address++;

	content += ee_read_byte(address);
	content <<= 8;
	address++;

	content += ee_read_byte(address);

return content;
}
